@@ -6,9 +6,13 @@ from pyspark.ml.param import Param
 from pyspark.sql.dataframe import DataFrame
 
 from spark_pipeline_framework.logger.yarn_logger import get_logger
-from spark_pipeline_framework.progress_logger.progress_log_metric import ProgressLogMetric
+from spark_pipeline_framework.progress_logger.progress_log_metric import (
+    ProgressLogMetric,
+)
 from spark_pipeline_framework.progress_logger.progress_logger import ProgressLogger
-from spark_pipeline_framework.transformers.framework_transformer.v1.framework_transformer import FrameworkTransformer
+from spark_pipeline_framework.transformers.framework_transformer.v1.framework_transformer import (
+    FrameworkTransformer,
+)
 
 
 class FrameworkSqlTransformer(FrameworkTransformer):
@@ -22,7 +26,7 @@ class FrameworkSqlTransformer(FrameworkTransformer):
         name: Optional[str] = None,
         parameters: Optional[Dict[str, Any]] = None,
         progress_logger: Optional[ProgressLogger] = None,
-        verify_count_remains_same: bool = False
+        verify_count_remains_same: bool = False,
     ) -> None:
         super().__init__(
             name=name, parameters=parameters, progress_logger=progress_logger
@@ -62,7 +66,7 @@ class FrameworkSqlTransformer(FrameworkTransformer):
         name: Optional[str] = None,
         parameters: Optional[Dict[str, Any]] = None,
         progress_logger: Optional[ProgressLogger] = None,
-        verify_count_remains_same: bool = False
+        verify_count_remains_same: bool = False,
     ) -> None:
         kwargs = self._input_kwargs
         super().setParams(
@@ -81,9 +85,7 @@ class FrameworkSqlTransformer(FrameworkTransformer):
         ):
             if progress_logger and name:
                 # mlflow opens .txt files inline so we use that extension
-                progress_logger.log_artifact(
-                    key=f"{name}.sql.txt", contents=sql_text
-                )
+                progress_logger.log_artifact(key=f"{name}.sql.txt", contents=sql_text)
                 progress_logger.write_to_log(name=name, message=sql_text)
             try:
                 df = df.sql_ctx.sql(sql_text)
@@ -93,14 +95,12 @@ class FrameworkSqlTransformer(FrameworkTransformer):
                 raise
 
             df.createOrReplaceTempView(view)
-            self.logger.info(
-                f"GenericSqlTransformer [{name}] finished running SQL"
-            )
+            self.logger.info(f"GenericSqlTransformer [{name}] finished running SQL")
 
         return df
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def setSql(self, value: str) -> 'FrameworkSqlTransformer':
+    def setSql(self, value: str) -> "FrameworkSqlTransformer":
         self._paramMap[self.sql] = value
         return self
 
@@ -109,7 +109,7 @@ class FrameworkSqlTransformer(FrameworkTransformer):
         return self.getOrDefault(self.sql)  # type: ignore
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def setView(self, value: str) -> 'FrameworkSqlTransformer':
+    def setView(self, value: str) -> "FrameworkSqlTransformer":
         self._paramMap[self.view] = value
         return self
 
@@ -118,7 +118,7 @@ class FrameworkSqlTransformer(FrameworkTransformer):
         return self.getOrDefault(self.view)  # type: ignore
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def setLogSql(self, value: bool) -> 'FrameworkSqlTransformer':
+    def setLogSql(self, value: bool) -> "FrameworkSqlTransformer":
         self._paramMap[self.log_sql] = value
         return self
 
@@ -127,14 +127,10 @@ class FrameworkSqlTransformer(FrameworkTransformer):
         return self.getOrDefault(self.log_sql)  # type: ignore
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def setVerifyCountRemainsSame(
-        self, value: bool
-    ) -> 'FrameworkSqlTransformer':
+    def setVerifyCountRemainsSame(self, value: bool) -> "FrameworkSqlTransformer":
         self._paramMap[self.verify_count_remains_same] = value
         return self
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def getVerifyCountRemainsSame(self) -> bool:
-        return self.getOrDefault(  # type: ignore
-            self.verify_count_remains_same
-        )
+        return self.getOrDefault(self.verify_count_remains_same)  # type: ignore
