@@ -6,16 +6,18 @@ from pyspark.sql.session import SparkSession
 from pyspark.sql.types import StructType
 
 from library.features.carriers.v1.features_carriers_v1 import FeaturesCarriersV1
-from library.features.carriers_python.v1.features_carriers_python_v1 import FeaturesCarriersPythonV1
+from library.features.carriers_python.v1.features_carriers_python_v1 import (
+    FeaturesCarriersPythonV1,
+)
 from spark_pipeline_framework.pipelines.framework_pipeline import FrameworkPipeline
 from spark_pipeline_framework.progress_logger.progress_logger import ProgressLogger
-from spark_pipeline_framework.transformers.framework_csv_loader.v1.framework_csv_loader import FrameworkCsvLoader
+from spark_pipeline_framework.transformers.framework_csv_loader.v1.framework_csv_loader import (
+    FrameworkCsvLoader,
+)
 
 
 class MyPipeline(FrameworkPipeline):
-    def __init__(
-        self, parameters: Dict[str, Any], progress_logger: ProgressLogger
-    ):
+    def __init__(self, parameters: Dict[str, Any], progress_logger: ProgressLogger):
         super(MyPipeline, self).__init__(
             parameters=parameters, progress_logger=progress_logger
         )
@@ -25,21 +27,21 @@ class MyPipeline(FrameworkPipeline):
                     view="flights",
                     path_to_csv=parameters["flights_path"],
                     parameters=parameters,
-                    progress_logger=progress_logger
+                    progress_logger=progress_logger,
                 ),
                 FeaturesCarriersV1(
                     parameters=parameters, progress_logger=progress_logger
                 ).transformers,
                 FeaturesCarriersPythonV1(
                     parameters=parameters, progress_logger=progress_logger
-                ).transformers
+                ).transformers,
             ]
         )
 
 
 def test_can_run_framework_pipeline(spark_session: SparkSession) -> None:
     # Arrange
-    data_dir: Path = Path(__file__).parent.joinpath('./')
+    data_dir: Path = Path(__file__).parent.joinpath("./")
     flights_path: str = f"file://{data_dir.joinpath('flights.csv')}"
 
     schema = StructType([])
